@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -113,9 +113,9 @@ class SyL_ConfigActions extends SyL_Config
      */
     function parseXml()
     {
-        if (SYL_WEBAPP_CACHE_DIR) {
+        if (SYL_PROJECT_CACHE_DIR) {
             // åѤ
-            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'actions', $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName());
+            $cache =& $this->getCacheObject(SYL_PROJECT_CACHE_DIR . 'actions', $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName());
             if ($cache) {
                 parent::parseXml();
                 // åѥ᡼¸
