@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.15 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.16 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.15 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.16 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -113,9 +113,9 @@ class SyL_ConfigFilters extends SyL_Config
      */
     function parseXml()
     {
-        if (SYL_WEBAPP_CACHE_DIR) {
+        if (SYL_PROJECT_CACHE_DIR) {
             // åѤ
-            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'filters', $this->action_file);
+            $cache =& $this->getCacheObject(SYL_PROJECT_CACHE_DIR . 'filters', $this->action_file);
             if ($cache) {
                 parent::parseXml();
                 $cache->write($this->getCache());
