@@ -27,39 +27,28 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.11 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.12 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ƥ饹
+ * եؤΥϥ饹
  */
 require_once 'SyL_LoggerFile.php';
 
 /**
- * եؤΥϥ饹
+ * 󥽡ؤΥϥ饹
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.11 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.12 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerConsole extends SyL_LoggerFile
 {
-    /**
-     * 󥹥ȥ饯
-     * 
-     * @access public
-     * @param boolean ¨ϥե饰 true: ¨ϡfalse: ꥯȽλ˽
-     */
-    function SyL_LoggerConsole($immediate)
-    {
-        parent::SyL_LoggerFile($immediate);
-    }
-
     /**
      * ץ
      *
