@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.11 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.12 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_File.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.11 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.12 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerFile extends SyL_Logger
@@ -56,17 +56,6 @@ class SyL_LoggerFile extends SyL_Logger
      */
     var $writer = null;
 
-    /**
-     * 󥹥ȥ饯
-     * 
-     * @access public
-     * @param boolean ¨ϥե饰 true: ¨ϡfalse: ꥯȽλ˽
-     */
-    function SyL_LoggerFile($immediate)
-    {
-        parent::SyL_Logger($immediate);
-    }
-
     /**
      * ץ
      *
@@ -96,7 +85,7 @@ class SyL_LoggerFile extends SyL_Logger
     function log($level, $message)
     {
         if ($level != '') {
-            $message = sprintf ('%s [%s] %s "%s %s" %s', date('Y-m-d H:i:s'), $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
+            $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
         }
         if ($this->immediate || ($level == '')) {
             $this->writer->write($message . $this->eof);
