@@ -27,34 +27,23 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.10 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.11 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * HTML̤ؤʸϥ饹
+ * ֥饦ؤΥϥ饹
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.10 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.11 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerHtml extends SyL_Logger
 {
-    /**
-     * 󥹥ȥ饯
-     * 
-     * @access public
-     * @param boolean ¨ϥե饰 true: ¨ϡfalse: ꥯȽλ˽
-     */
-    function SyL_LoggerHtml($immediate)
-    {
-        parent::SyL_Logger($immediate);
-    }
-
     /**
      * ֥饦˥åϤ
      *
@@ -65,7 +54,7 @@ class SyL_LoggerHtml extends SyL_Logger
     function log($level, $message)
     {
         if ($level != '') {
-            $message = sprintf ('%s [%s] %s "%s %s" %s', date('Y-m-d H:i:s'), $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
+            $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
         }
         if ($this->immediate || ($level == '')) {
             echo '<font color="CC0000">' . $message . '</font><br>' . $this->eof;
