@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -162,7 +162,7 @@ echo "</pre>";
                     // ٥Ⱥ
                     $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
                     if ($keys['force']) {
-                        trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_WEBAPP_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
+                        trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_PROJECT_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
                     }
                     continue;
                 }
@@ -263,7 +263,7 @@ echo "</pre>";
                         $this->setComponent($name, $component);
                     } else {
                         if ($keys['force']) {
-                            trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_WEBAPP_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
+                            trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_PROJECT_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
                         }
                     }
                     break;
@@ -359,15 +359,15 @@ echo "</pre>";
         if (is_file(SYL_INCLUDE_DIR . "/{$file}")) {
             // SyLǥ쥯ȥ꤫Υѥ
             include_once SYL_INCLUDE_DIR . "/{$file}";
-        } else if (is_file(SYL_WEBAPP_LIB_DIR . "/{$file}")) {
+        } else if (is_file(SYL_PROJECT_LIB_DIR . "/{$file}")) {
             // ץꥱǥ쥯ȥ꤫Υѥ
-            include_once SYL_WEBAPP_LIB_DIR . "/{$file}";
+            include_once SYL_PROJECT_LIB_DIR . "/{$file}";
         } else if (is_file($file)) {
             // եѥ
             include_once $file;
         } else {
             // ݡͥȥե뤬̵
-            $this->log('info', "Component include failed: file not found (" . SYL_INCLUDE_DIR . "/{$file} or " . SYL_WEBAPP_LIB_DIR . "/{$file} or {$file})");
+            $this->log('info', "Component include failed: file not found (" . SYL_INCLUDE_DIR . "/{$file} or " . SYL_PROJECT_LIB_DIR . "/{$file} or {$file})");
             return false;
         }
         return true;
