@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.4 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,6 +36,12 @@
  * ܾ󥯥饹
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
+/**
+ * PHPեɥ饹
+ *
+ * ե졼ǤϻѤƤʤޤǥ¦Υإѥ饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
 
 /**
  * ե졼饹
@@ -44,7 +50,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.4 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
