@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.21 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.21 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -167,30 +167,25 @@ class SyL_Controller
      */
     function SyL_Controller($config)
     {
-        // 󥭡
-        if (isset($config['action_key']) && $config['action_key']) {
-            define('SYL_ACTION_KEY', $config['action_key']);
-        } else {
-            trigger_error("[SyL error] Action_key not found", E_USER_ERROR);
-        }
-
         // ץꥱ̾
         if (!isset($config['app_name']) || !$config['app_name']) {
             trigger_error("[SyL error] App_name not found", E_USER_ERROR);
         }
 
+        // 󥭡
+        define('SYL_ACTION_KEY', (isset($config['action_key']) && $config['action_key']) ? $config['action_key'] : 'action');
         // ǥХå٥
-        define('SYL_DEBUG', (isset($config['debug']) && is_numeric($config['debug'])) ? $config['debug'] : SYL_LOG_NOTICE);
-        // WEBץꥱǥ쥯ȥ
-        define('SYL_WEBAPP_DIR', (isset($config['webapp_dir']) && $config['webapp_dir']) ? $config['webapp_dir'] : SYL_DIR . '/webapp');
+        define('SYL_DEBUG', (isset($config['debug']) && is_numeric($config['debug'])) ? $config['debug'] : SYL_LOG_WARN);
+        // ץȥǥ쥯ȥ
+        define('SYL_PROJECT_DIR', (isset($config['webapp_dir']) && $config['webapp_dir']) ? $config['webapp_dir'] : SYL_DIR . '/webapp');
         // å
-        define('SYL_WEBAPP_CACHE_DIR', (isset($config['cache_dir']) && $config['cache_dir']) ? SYL_WEBAPP_DIR . $config['cache_dir'] : false);
-        // WEBץꥱեǥ쥯ȥ
-        define('SYL_WEBAPP_CONFIG_DIR',  SYL_WEBAPP_DIR . '/config');
-        // WEBץꥱ饤֥ǥ쥯ȥ
-        define('SYL_WEBAPP_LIB_DIR',  SYL_WEBAPP_DIR . '/lib');
+        define('SYL_PROJECT_CACHE_DIR', (isset($config['cache_dir']) && $config['cache_dir']) ? SYL_PROJECT_DIR . $config['cache_dir'] : false);
+        // ץեǥ쥯ȥ
+        define('SYL_PROJECT_CONFIG_DIR',  SYL_PROJECT_DIR . '/config');
+        // ץȥ饤֥ǥ쥯ȥ
+        define('SYL_PROJECT_LIB_DIR',  SYL_PROJECT_DIR . '/lib');
         // ץꥱǥ쥯ȥ
-        define('SYL_APP_DIR', SYL_WEBAPP_DIR . '/app/' . $config['app_name']);
+        define('SYL_APP_DIR', SYL_PROJECT_DIR . '/app/' . $config['app_name']);
 
         // ɤ߹
         call_user_func(array(&$this, 'readDefines'));
@@ -255,7 +250,7 @@ class SyL_Controller
             array_shift($config_files);
         }
         // Хͤɤ߹
-        $config_files[] = SYL_WEBAPP_CONFIG_DIR . "/{$this->defines_file_name}";
+        $config_files[] = SYL_PROJECT_CONFIG_DIR . "/{$this->defines_file_name}";
 
         // åѤʤ
         $config =& SyL_Config::getObject('defines', $config_files, $this);
