@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.10 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.11 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.10 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.11 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
@@ -47,42 +47,50 @@ class SyL_Logger
     /**
      * ꥯȥ᥽å
      * 
-     * @access public
+     * @access protected
      * @var string
      */
     var $request_method;
     /**
      * 饤IPɥ쥹
      * 
-     * @access public
+     * @access protected
      * @var string
      */
     var $remote_addr;
     /**
      * ꥯURL
      * 
-     * @access public
+     * @access protected
      * @var string
      */
     var $request_uri;
     /**
      * ¨ϥե饰
      * 
-     * @access public
+     * @access protected
      * @var bool
      */
     var $immediate = true;
     /**
      * ¨ϤǤϤʤ˳ǼХåե
      * 
-     * @access public
+     * @access protected
      * @var array
      */
     var $buffer = array();
+    /**
+     * եեޥå
+     * dateեޥå
+     * 
+     * @access protected
+     * @var string
+     */
+    var $datetime_format = 'Y-m-d H:i:s';
     /**
      * ԥ
      * 
-     * @access public
+     * @access protected
      * @var string
      */
     var $eof = "\r\n";
@@ -95,9 +103,15 @@ class SyL_Logger
      */
     function SyL_Logger($immediate=true)
     {
-        $this->request_method = isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : '';
-        $this->remote_addr    = isset($_SERVER['REMOTE_ADDR'])    ? $_SERVER['REMOTE_ADDR']    : '';
-        $this->request_uri    = isset($_SERVER['REQUEST_URI'])    ? $_SERVER['REQUEST_URI']    : '';
+        if (SYL_ENV_TYPE == 'cmd') {
+            $this->request_method = 'php';
+            $this->remote_addr    = '127.0.0.1';
+            $this->request_uri    = isset($_SERVER['SCRIPT_FILENAME']) ? $_SERVER['SCRIPT_FILENAME'] : '';
+        } else {
+            $this->request_method = isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : '';
+            $this->remote_addr    = isset($_SERVER['REMOTE_ADDR'])    ? $_SERVER['REMOTE_ADDR']    : '';
+            $this->request_uri    = isset($_SERVER['REQUEST_URI'])    ? $_SERVER['REQUEST_URI']    : '';
+        }
         $this->immediate = $immediate;
     }
 
@@ -112,9 +126,9 @@ class SyL_Logger
     function &getLogger($type, $immediate=true)
     {
         // ƥꥪ֥ɤ߹
-        $logger_class = 'SyL_Logger' . ucfirst($type);
-        include_once SYL_INCLUDE_DIR . '/framework/Logger/' . $logger_class . '.php';
-        $logger_object =& new $logger_class($immediate);
+        $classname = 'SyL_Logger' . ucfirst($type);
+        include_once SYL_INCLUDE_DIR . "/framework/Logger/{$classname}.php";
+        $logger_object =& new $classname($immediate);
         return $logger_object;
     }
 
@@ -148,10 +162,10 @@ class SyL_Logger
         if (!$this->immediate) {
             while (true) {
                 $buffer = array_shift($this->buffer);
-                if (($buffer === false) || ($buffer === null)) {
+                if (!$buffer) {
                     break;
                 }
-                $this->log( '', $buffer );
+                $this->log('', $buffer);
             }
         }
     }
