@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.12 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.13 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.12 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.13 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
@@ -110,10 +110,8 @@ class SyL_Request
      */
      function createParameter()
      {
-         if ($this->parameter == null) {
-             include_once SYL_INCLUDE_DIR . "/framework/Request/SyL_RequestParameter.php";
-             $this->parameter =& new $classname();
-         }
+         include_once SYL_INCLUDE_DIR . "/framework/Request/SyL_RequestParameter.php";
+         $this->parameter =& new $classname();
      }
 
     /**
@@ -123,10 +121,8 @@ class SyL_Request
      */
      function createSession()
      {
-         if ($this->session == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestSession.php';
-             $this->session =& new SyL_RequestSession();
-         }
+         include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestSession.php';
+         $this->session =& new SyL_RequestSession();
      }
 
     /**
@@ -136,10 +132,8 @@ class SyL_Request
      */
      function createCookie()
      {
-         if ($this->cookie == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestCookie.php';
-             $this->cookie =& new SyL_RequestCookie();
-         }
+         include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestCookie.php';
+         $this->cookie =& new SyL_RequestCookie();
      }
 
     /**
@@ -149,10 +143,8 @@ class SyL_Request
      */
      function createFile()
      {
-         if ($this->files == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestFile.php';
-             $this->files =& new SyL_RequestFile();
-         }
+         include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestFile.php';
+         $this->files =& new SyL_RequestFile();
      }
 
     /**
@@ -164,7 +156,7 @@ class SyL_Request
      */
     function setParameter($name, $value)
     {
-        if ($this->session == null) {
+        if ($this->parameter === null) {
             $this->createParameter();
         }
         $this->parameter->set($name, $value);
@@ -179,7 +171,7 @@ class SyL_Request
      */
     function getParameter($name)
     {
-        if ($this->session == null) {
+        if ($this->parameter === null) {
             $this->createParameter();
         }
         return $this->parameter->get($name);
@@ -193,7 +185,7 @@ class SyL_Request
      */
     function &getParameterObject()
     {
-        if ($this->session == null) {
+        if ($this->parameter === null) {
             $this->createParameter();
         }
         return $this->parameter;
@@ -208,7 +200,7 @@ class SyL_Request
      */
     function setSession($name, $value)
     {
-        if ($this->session == null) {
+        if ($this->session === null) {
             $this->createSession();
         }
         $this->session->set($name, $value);
@@ -223,7 +215,7 @@ class SyL_Request
      */
     function getSession($name)
     {
-        if ($this->session == null) {
+        if ($this->session === null) {
             $this->createSession();
         }
         return (($this->session != null) ? $this->session->get($name) : null);
@@ -237,7 +229,7 @@ class SyL_Request
      */
     function &getSessionObject()
     {
-        if ($this->session == null) {
+        if ($this->session === null) {
             $this->createSession();
         }
         return $this->session;
@@ -252,7 +244,7 @@ class SyL_Request
      */
     function setCookie($name, $value)
     {
-        if ($this->cookie == null) {
+        if ($this->cookie === null) {
             $this->createCookie();
         }
         $this->cookie->set($name, $value);
@@ -267,7 +259,7 @@ class SyL_Request
      */
     function getCookie($name)
     {
-        if ($this->cookie == null) {
+        if ($this->cookie === null) {
             $this->createCookie();
         }
         return $this->cookie->get($name);
@@ -281,7 +273,7 @@ class SyL_Request
      */
     function &getCookieObject()
     {
-        if ($this->cookie == null) {
+        if ($this->cookie === null) {
             $this->createCookie();
         }
         return $this->cookie;
@@ -296,7 +288,7 @@ class SyL_Request
      */
     function getFile($name)
     {
-        if ($this->files == null) {
+        if ($this->files === null) {
             $this->createFile();
         }
         return $this->files->get($name);
@@ -310,7 +302,7 @@ class SyL_Request
      */
     function &getFileObject()
     {
-        if ($this->files == null) {
+        if ($this->files === null) {
             $this->createFile();
         }
         return $this->files;
