@@ -6,11 +6,13 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: template.php,v 1.5 2007/01/28 07:13:59 seasonstream Exp $
+ * @version   CVS: $Id: template.php,v 1.6 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Template
 {
+    var $c_template; // 󥸥
+
     /**
      * 󥹥ȥ饯
      *
@@ -27,11 +29,11 @@ class Template
      * @param object ܾ󥪥֥
      * @param object ݡͥȥ᥽åɥ֥
      */
-    function execute(&$cmd, &$cm)
+    function execute(&$data, &$context)
     {
-        $project_dir    = $cmd->getArg('-d');
-        $app_name       = $cmd->getArg('-w');
-        $template_files = $cmd->getArg('-t');
+        $project_dir    = $data->get('d');
+        $app_name       = $data->get('w');
+        $template_files = $data->get('t');
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
@@ -102,7 +104,7 @@ class Template
         // -------------------------------------------------
         // ƥץ졼ȥե
         // -------------------------------------------------
-        $cm->triggerApp('c_template', $project_dir, $app_name, $template_files);
+        $this->c_template->trigger($project_dir, $app_name, $template_files);
     }
 
 }
