@@ -3,10 +3,10 @@
  * եݡͥȥ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: C_CreateAction.php,v 1.8 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: C_CreateAction.php,v 1.9 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class C_CreateAction
@@ -33,7 +33,7 @@ class C_CreateAction
         if (file_exists("{$project_dir}var/skel-templates/action.php")) {
             $action_template = "{$project_dir}var/skel-templates/action.php";
         } else {
-            $action_template = SYL_WEBAPP_DIR . '/var/skel-templates/action.php';
+            $action_template = SYL_PROJECT_DIR . '/var/skel-templates/action.php';
         }
         $contents = file_get_contents($action_template);
 
