@@ -3,10 +3,10 @@
  * ץꥱǥ쥯ȥݡͥȥ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: C_CreateApplication.php,v 1.8 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: C_CreateApplication.php,v 1.9 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class C_CreateApplication
@@ -45,28 +45,28 @@ class C_CreateApplication
         if (file_exists("{$project_dir}var/skel-templates/actions.xml")) {
             copy("{$project_dir}var/skel-templates/actions.xml", "{$app_dir}actions.xml");
         } else {
-            copy(SYL_WEBAPP_DIR . '/var/skel-templates/actions.xml', "{$app_dir}actions.xml");
+            copy(SYL_PROJECT_DIR . '/var/skel-templates/actions.xml', "{$app_dir}actions.xml");
         }
 
         echo "  copying file {$app_dir}defines.xml\n"; ob_flush();
         if (file_exists("{$project_dir}var/skel-templates/defines_app.xml")) {
             copy("{$project_dir}var/skel-templates/defines_app.xml", "{$app_dir}defines.xml");
         } else {
-            copy(SYL_WEBAPP_DIR . '/var/skel-templates/defines_app.xml', "{$app_dir}defines.xml");
+            copy(SYL_PROJECT_DIR . '/var/skel-templates/defines_app.xml', "{$app_dir}defines.xml");
         }
 
         echo "  copying file {$app_dir}filters.xml\n"; ob_flush();
         if (file_exists("{$project_dir}var/skel-templates/filters.xml")) {
             copy("{$project_dir}var/skel-templates/filters.xml", "{$app_dir}filters.xml");
         } else {
-            copy(SYL_WEBAPP_DIR . '/var/skel-templates/filters.xml', "{$app_dir}filters.xml");
+            copy(SYL_PROJECT_DIR . '/var/skel-templates/filters.xml', "{$app_dir}filters.xml");
         }
 
         echo "  copying file {$app_dir}layouts.xml\n"; ob_flush();
         if (file_exists("{$project_dir}var/skel-templates/layouts.xml")) {
             copy("{$project_dir}var/skel-templates/layouts.xml", "{$app_dir}layouts.xml");
         } else {
-            copy(SYL_WEBAPP_DIR . '/var/skel-templates/layouts.xml', "{$app_dir}layouts.xml");
+            copy(SYL_PROJECT_DIR . '/var/skel-templates/layouts.xml', "{$app_dir}layouts.xml");
         }
     }
 }
