@@ -20,7 +20,7 @@ class {SYL_CLASS}
      * @param object ꥯȥ֥
      * @param object ǡ֥
      */
-    function execute(&$request, &$dm)
+    function execute(&$request, &$context)
     {
     }
 
